@@ -25,6 +25,7 @@ describe 'mistral::logging' do
      :log_date_format => '%Y-%m-%d %H:%M:%S',
      :use_syslog => true,
      :use_json => true,
+     :use_journal => true,
      :use_stderr => false,
      :log_facility => 'LOG_FOO',
      :log_dir => '/var/log',
@@ -59,6 +60,7 @@ describe 'mistral::logging' do
       is_expected.to contain_oslo__log('mistral_config').with(
         :use_syslog          => '<SERVICE DEFAULT>',
         :use_json            => '<SERVICE DEFAULT>',
+        :use_journal         => '<SERVICE DEFAULT>',
         :use_stderr          => '<SERVICE DEFAULT>',
         :syslog_log_facility => '<SERVICE DEFAULT>',
         :log_dir             => '/var/log/mistral',
@@ -72,6 +74,7 @@ describe 'mistral::logging' do
       is_expected.to contain_oslo__log('mistral_config').with(
         :use_syslog          => true,
         :use_json            => true,
+        :use_journal         => true,
         :use_stderr          => false,
         :syslog_log_facility => 'LOG_FOO',
         :log_dir             => '/var/log',
